@@ -10,7 +10,7 @@ from pathlib import Path
 import vdf
 
 from .flatpak import is_flatpak_sandbox
-from .util import lower_dict
+from .util import lower_dict, is_steam_deck
 
 __all__ = (
     "COMMON_STEAM_DIRS", "SteamApp", "find_steam_installations",
@@ -21,7 +21,7 @@ __all__ = (
     "get_custom_compat_tool_installations_in_dir",
     "get_custom_compat_tool_installations", "find_current_steamid3",
     "get_appid_from_shortcut", "get_custom_windows_shortcuts",
-    "get_steam_apps", "is_steam_deck"
+    "get_steam_apps"
 )
 
 COMMON_STEAM_DIRS = [
@@ -1070,7 +1070,7 @@ def get_appid_from_shortcut(target, name):
     return result >> 32
 
 
-def get_custom_windows_shortcuts(steam_path):
+def get_custom_windows_shortcuts(steam_path, steam_lib_paths):
     """
     Get a list of custom shortcuts for Windows applications as a list
     of SteamApp objects
@@ -1113,11 +1113,33 @@ def get_custom_windows_shortcuts(steam_path):
                 target=shortcut_data["exe"], name=shortcut_data["appname"]
             )
 
-        prefix_path = \
-            steam_path / "steamapps" / "compatdata" / str(appid) / "pfx"
+        prefix_path = find_appid_proton_prefix(
+            appid=appid, steam_lib_paths=steam_lib_paths
+        )
+        if not prefix_path:
+            logger.info(
+                "Shortcut %s (%s) does not have a prefix. "
+                "It's either not a Proton app or it hasn't been launched yet.",
+                shortcut_data["appname"], appid
+            )
+            continue
+
         install_path = Path(shortcut_data["startdir"].strip('"'))
 
-        if not prefix_path.is_dir():
+        try:
+            # Check that we have permission to access the installation
+            # directory, whether it exists or not. Any attempts to check
+            # any files will fail later if this isn't done.
+            install_path.is_dir()
+
+            if not prefix_path.is_dir():
+                continue
+        except PermissionError as exc:
+            logger.warning(
+                "Skipping shortcut %s due to insufficient permissions. "
+                "Error: %s",
+                shortcut_data["appname"], str(exc)
+            )
             continue
 
         steam_apps.append(
@@ -1157,10 +1179,17 @@ def get_steam_apps(steam_root, steam_path, steam_lib_paths):
     steam_apps = []
 
     for path in steam_lib_paths:
-        if not path.is_dir():
+        try:
+            if not path.is_dir():
+                logger.warning(
+                    "Steam library folder %s not found. Protontricks "
+                    "might not have access to the directory.",
+                    str(path)
+                )
+                continue
+        except PermissionError:
             logger.warning(
-                "Steam library folder %s not found. Protontricks "
-                "might not have access to the directory.",
+                "Skipping library folder %s due to insufficient permissions",
                 str(path)
             )
             continue
@@ -1196,15 +1225,26 @@ def get_steam_apps(steam_root, steam_path, steam_lib_paths):
                 )
 
         for manifest_path in appmanifest_paths:
-            steam_app = SteamApp.from_appmanifest(
-                manifest_path, steam_lib_paths=steam_lib_paths
-            )
+            try:
+                steam_app = SteamApp.from_appmanifest(
+                    manifest_path, steam_lib_paths=steam_lib_paths
+                )
+            except PermissionError as exc:
+                logger.warning(
+                    "Could not load manifest %s due to insufficient "
+                    "permissions. Error: %s",
+                    str(manifest_path), str(exc)
+                )
+                steam_app = None
+
             if steam_app:
                 steam_apps.append(steam_app)
 
     # Get the custom compatibility tools and non-Steam shortcuts as well
     steam_apps += get_custom_compat_tool_installations(steam_root=steam_root)
-    steam_apps += get_custom_windows_shortcuts(steam_path=steam_path)
+    steam_apps += get_custom_windows_shortcuts(
+        steam_path=steam_path, steam_lib_paths=steam_lib_paths
+    )
 
     # Exclude games that haven't been launched yet
     steam_apps = [
@@ -1220,20 +1260,3 @@ def get_steam_apps(steam_root, steam_path, steam_lib_paths):
     steam_apps.sort(key=lambda app: app.name)
 
     return steam_apps
-
-
-def is_steam_deck():
-    """
-    Check if we're running on a Steam Deck
-    """
-    for path in OS_RELEASE_PATHS:
-        try:
-            lines = Path(path).read_text("utf-8").split("\n")
-        except FileNotFoundError:
-            continue
-
-        if "ID=steamos" in lines and "VARIANT_ID=steamdeck" in lines:
-            logger.info("The current device is a Steam Deck")
-            return True
-
-    return False
